pub fn save_to_file(
path: &Path,
records: &[CacheRecord],
) -> Result<(), SerializeError>Expand description
Persist records to the file at path, creating or truncating it.
Equivalent to opening the file and calling serialize.
pub fn save_to_file(
path: &Path,
records: &[CacheRecord],
) -> Result<(), SerializeError>Persist records to the file at path, creating or truncating it.
Equivalent to opening the file and calling serialize.