Module distributed_cache

Module distributed_cache 

Distributed cache coordination primitives.

This module provides the building blocks for routing cache operations across a cluster of nodes:

Structs

CacheCoordinator
Cluster-level coordinator.
ConsistentHash
Virtual-node consistent-hash ring.
DistributedCacheClient
Per-node client that wraps a ConsistentHash ring and provides key routing from the perspective of local_node.
NodeId
Opaque identifier for a cache cluster node.
ReplicationFactor
Quorum-based replication configuration.