ReplicationFactor

Struct ReplicationFactor 

pub struct ReplicationFactor {
    pub reads: u8,
    pub writes: u8,
}
Quorum-based replication configuration.

A write quorum requires acknowledgement from at least writes nodes; a read quorum requires responses from at least reads nodes.

Fields

reads: u8

Number of read responses required to satisfy a quorum.

writes: u8

Number of write acknowledgements required to satisfy a quorum.

Implementations

Source

impl ReplicationFactor

pub fn new(reads: u8, writes: u8) -> Self

Construct a new ReplicationFactor.

pub fn is_quorum_read_met(&self, responses: u8) -> bool

Return true if responses meets or exceeds the read quorum.

pub fn is_quorum_write_met(&self, responses: u8) -> bool

Return true if responses meets or exceeds the write quorum.

pub fn rf3() -> Self

Convenience constructor for a standard RF-3 cluster (R=2, W=2).

pub fn rf3_strong() -> Self

Convenience constructor for a strongly consistent RF-3 cluster (R+W > N, so R=3, W=3 for N=3).