pub enum SegmentCacheError {
CacheFull,
SegmentTooLarge,
DuplicateSegment,
}Expand description
Errors that can occur during segment cache operations.
Variants
CacheFull
The cache is full and no segments could be evicted to make room.
SegmentTooLarge
The segment data exceeds the entire byte budget of the cache.
DuplicateSegment
A segment with the same (stream_id, sequence) already exists.