SegmentCacheConfig

Struct SegmentCacheConfig 

pub struct SegmentCacheConfig {
    pub max_segments: usize,
    pub max_bytes: u64,
    pub prefetch_ahead: u8,
    pub evict_played: bool,
}
Configuration for SegmentCache.

Fields

max_segments: usize

Maximum number of segments across all streams.

max_bytes: u64

Maximum total byte budget across all segments.

prefetch_ahead: u8

How many segments ahead of current_seq to include in prefetch hints.

evict_played: bool

When true, segments marked as played are eligible for immediate eviction ahead of unplayed segments during the next capacity check.