pub enum SlabError {
SlabIndexOutOfRange(usize, usize),
SlotIndexOutOfRange(usize, usize, usize),
SlotAlreadyFree {
slab: usize,
slot: usize,
},
}Expand description
Errors returned by SlabAllocator.
Variants
SlabIndexOutOfRange(usize, usize)
A handle points outside the slab array bounds.
SlotIndexOutOfRange(usize, usize, usize)
A slot index is outside the capacity of the addressed slab.
SlotAlreadyFree
The addressed slot is free and cannot be read.