pub struct SlotHandle {
pub slab: usize,
pub index: usize,
}Expand description
An opaque handle to a slot in a SlabAllocator.
Handles are returned by allocate and are valid until free is
called on the same handle. Using a freed handle is safe: get and
get_mut return Err(SlabError::SlotAlreadyFree).
Fields
slab: usizeIndex into the slab array.
index: usizeIndex within the slab.