pub struct TierStats {
pub name: String,
pub hits: u64,
pub size_used_bytes: usize,
pub entry_count: usize,
pub promotions: u64,
pub compressions: u64,
}Expand description
Per-tier statistics snapshot.
Fields
name: StringHuman-readable tier name.
hits: u64Number of cache hits served by this tier.
size_used_bytes: usizeNumber of bytes currently stored in this tier.
entry_count: usizeNumber of distinct entries currently in this tier.
promotions: u64Number of promotions from this tier to the tier above.
compressions: u64Number of times an entry was compressed before storage.