CacheStats

Struct CacheStats 

pub struct CacheStats {
    pub hits: u64,
    pub misses: u64,
    pub evictions: u64,
    pub total_size_bytes: usize,
    pub capacity: usize,
    pub entry_count: usize,
    pub ttl_expirations: u64,
    pub pinned_count: usize,
}
Snapshot of cache statistics.

Fields

hits: u64

Total number of successful cache lookups.

misses: u64

Total number of failed cache lookups.

evictions: u64

Total number of entries evicted to make room for new ones.

total_size_bytes: usize

Sum of size_bytes for all currently resident entries.

capacity: usize

Maximum number of entries the cache will hold before evicting.

entry_count: usize

Number of entries currently resident in the cache.

ttl_expirations: u64

Number of entries that expired via TTL.

pinned_count: usize

Number of pinned entries currently in the cache.