pub struct NegativeCache { /* private fields */ }Expand description
A TTL-keyed negative result cache.
Implementations
Sourceimpl NegativeCache
impl NegativeCache
Sourcepub fn insert_miss(&mut self, key: &str, now_ms: u64)
pub fn insert_miss(&mut self, key: &str, now_ms: u64)
Record key as a known miss at timestamp now_ms.
If an entry for key already exists it is overwritten with the new
timestamp (refreshing the TTL).
Sourcepub fn is_known_miss(&self, key: &str, now_ms: u64) -> bool
pub fn is_known_miss(&self, key: &str, now_ms: u64) -> bool
Returns true when key is a known miss that has not yet expired.
A miss entry at recorded_ms expires when now_ms >= recorded_ms + ttl_ms.
Sourcepub fn remove(&mut self, key: &str)
pub fn remove(&mut self, key: &str)
Remove the entry for key (e.g. after it has been successfully
populated in the origin cache).
Sourcepub fn evict_expired(&mut self, now_ms: u64)
pub fn evict_expired(&mut self, now_ms: u64)
Prune all entries that have expired by now_ms.