PrefetchStrategy

Enum PrefetchStrategy 

pub enum PrefetchStrategy {
    Sequential {
        lookahead: usize,
    },
    AccessPattern(Vec<String>),
}
Strategy controlling which keys the prefetcher will pre-warm.

Variants



Sequential

Assume keys are named like "segment-NNN".

On access to key "segment-N", pre-fetch "segment-(N+1)" through "segment-(N+lookahead)".

Fields

lookahead: usize

Number of keys to prefetch ahead of the current position.



AccessPattern(Vec<String>)

Follow a fixed ordered access pattern.

On access to key K, the next key in the pattern list is pre-warmed. When the end of the list is reached, the pattern wraps around.

Implementations

Source

impl PrefetchStrategy

pub fn predict_next(&self, current_key: &str) -> Vec<String>

Given the current_key, predict the next keys to prefetch.

Returns an empty vec when no prediction is possible.