SlotHandle

Struct SlotHandle 

pub struct SlotHandle {
    pub slab: usize,
    pub index: usize,
}
An opaque handle to a slot in a SlabAllocator.

Handles are returned by allocate and are valid until free is called on the same handle. Using a freed handle is safe: get and get_mut return Err(SlabError::SlotAlreadyFree).

Fields

slab: usize

Index into the slab array.

index: usize

Index within the slab.